function coeffs = legApproximateSignal( n_leg, signal, num_samples)
%
% coeffs = legApproximateSignal( n_leg, signal, num_samples)
%
% Approximate a signal, as specified by the function handle signal, in the 
% Legendre space 
%
% @param  n_leg     maximum degree of Legendre polynomials used
% @param  function  handle to the signal (parameter free, xvals as only
%                   input)
% @param  num_samples  number of samples used for approximation of basis
%                      function coefficients (using MC integration, 
%                      default: 1000000)
%
% @return  coeffs    Legendre basis coefficients

  defval( 'num_samples', 1000000);

  % xvals = halton( num_samples, 1);
  % use statistics toolbox (probably better quality through skipping, 
  % scrambling etc)
  p = haltonset( 1, 'Skip', 1e3, 'Leap', 1e2);
  p = scramble( p, 'RR2');
  xvals = net( p, num_samples);
  xvals = sort( (2.0 * xvals) - 1.0);

  % evaluate signal at sampling points
  fvals = signal( xvals);
  
  % compute approximation to coefficients
  coeffs = zeros( n_leg+1, 1);
  for( n = 0 : n_leg)
    
    leg_vals = legendre( n, xvals, 'norm');  
    coeffs(n+1) = (2.0 / num_samples) * dot( leg_vals(1,:), fvals);
    
  end
  
end