function K = legKernelMatrix( n_leg, lambdas)
%
% K = legKernelMatrix( n_leg, lambdas)
%
% Construct kernel matrix for space spanned by all Legendre polynomials up 
% to degree n_leg
%
% @retrun  K        kernel matrix
% @param   n_leg    maximum Legendre degree
% @param   lambdas  sampling points


  % generate values
  K = zeros( numel(lambdas), n_leg+1);

  % construct kernel matrix: 
  % - each column is fixed basis function
  % - each row is one fixed lambda
  for( n = 0 : n_leg)
    coeffs = legendre( n, lambdas, 'norm');
    K(:,n+1) = coeffs(1,:)';  
  end

end