% Biorthogonal basis pair

legInit;

%% Construct basis pair

% basis
% coeff_scaling = 0.55; 
% B = coeff_scaling * randn( n_leg+1, n_leg+1)
% assert( cond(B) < Inf);
% Fix B for reproducibility
B = [ -0.2254   -0.8068    0.1413   -0.9313   -0.2281;
      -0.2769   -0.8942   -0.5358   -0.2472    1.0517;
       0.6783   -1.0806   -0.6305   -0.0464   -0.2150;
       0.3357    1.4329    0.3012   -1.0956    0.2251;
       0.0325    0.5348    0.8608    0.4627   -0.6283]; 

% construct dual basis
Bt = inv(B);

% We hence have: 
% \bar{\phi}_i = B(i,:);
% \tilde{e}_j = Bt(:,j);

%% Verify biorthogonality of basis

err_biortho = 0.0;

for( i = 1 : n_leg+1)
  for( j = 1 : n_leg+1);
    
    % compute inner product of primary and dual basis functions:
    % < phi_i , phi_j >
    err = dot( B(i,:), Bt(:,j));
    
    % diagonal terms have to be 1.0
    if( i == j) err = err - 1.0; end;
    
    % pdate total error
    err_biortho = err_biortho + err;
    
  end
end

% Obviously, the biorthogonality satisfied by construction since 
% Bt = inv(B)
disp( sprintf( 'Error in biorthogonality = %e', err_biortho));

%% Verify basis property through reconstruction of arbitrary signal

v = rand( n_leg+1, 1);

% compute basis function coefficients using dual basis functions
v_i = zeros( n_leg+1, 1);
for( i = 1 : n_leg+1 )
  v_i(i) = dot( v, Bt(:,i));
end

% reconstruction
v_rec = zeros( n_leg+1, 1);
for( i = 1 : n_leg+1) 
  v_rec = v_rec + v_i(i) * B(i,:)';
end

% reconstruction error 
err_rec = norm( v - v_rec);

% demonstrate that basis and dual basis are interchangeable

% compute basis function coefficients using dual basis functions
v_i = zeros( n_leg+1, 1);
for( i = 1 : n_leg+1 )
  v_i(i) = dot( v, B(i,:));
end

% reconstruction
v_rec = zeros( n_leg+1, 1);
for( i = 1 : n_leg+1) 
  v_rec = v_rec + v_i(i) * Bt(:,i);
end

% accumulated reconstruction error
err_rec = err_rec + norm( v - v_rec);

% display result
disp( sprintf( 'Reconstruction error for random signal: %e', err_rec));

%% Display

% evaluate signals for plotting
xvals = [-1.0 : 0.001 : 1.0];
% basis functions
y_bf = legEvalSignal( n_leg, B, xvals);
% dual basis functions
y_dbf = legEvalSignal( n_leg, transpose(Bt), xvals);


% display basis functions
legPreVisualization();
for( n = 1 : n_leg)
  plot( xvals, y_bf(n,:),  ['-'], 'Color', cols(n+1,:));
end
legPostVisualization();
savePlot( h_fig, 'legPlotBiorthoBasis_a');

% display dual basis functions
legPreVisualization();
for( n = 1 : n_leg)
  plot( xvals, y_dbf(n,:),  ['--'], 'Color', cols(n+1,:));
end
legPostVisualization();
savePlot( h_fig, 'legPlotBiorthoBasis_b');
