% optimize sampling points and plot development of location, also 
% analyze difference in reconstruction error

legInit;

os_rate = 2.0;

% construct initial sampling points
% lambdas_init = rand( os_rate * (n_leg+1), 1);
% lambdas_init = sort( (2.0 * lambdas_init) - 1.0)';
% Fix points for reproducibility
lambdas_init = [-0.5263   -0.3424   -0.1966   -0.0870    0.0786    0.4660    0.5814    0.6152    0.8815    0.9417];

% initial condition number
cond_init = cond( legKernelMatrix( n_leg, lambdas_init));

% variable to retain optimization history
global history;
history.en = [];
history.lambdas = lambdas_init;

% generate lower and upper bounds for locations for optimization
lb = -1.0 * ones( size(lambdas_init));
ub = ones( size(lambdas_init));

% use active set algorithm 
options = optimset( 'Algorithm', 'active-set', ...
                    'OutputFcn', @legOptProgressCallback, ...
                    'Display', 'iter', ...
                    'TolFun', 1e-12, ...
                    'TolX', 1e-10, ...
                    'MaxFunEvals', 10000);

% construct the energy function that only has one parameter
enFunc = @(lambdas)legEnKernelMatrix( lambdas, n_leg);

% run optimization
[lambdas_opt] = fmincon( enFunc, lambdas_init, ...
                         [], [], [], [], ...
                         lb, ub, [], ...
                         options );

% 
cond_opt = cond( legKernelMatrix( n_leg, lambdas_opt));

%% Visualization 

legPreVisualization;
plot( [0:numel(history.en)-1], history.en + 1.0, '-r');
plot( [0:numel(history.en)-1], ones(size([0:numel(history.en)-1])), ...
      'Color', [0.8, 0.8, 0.8]);
legPostVisualization;
xlim( [0, numel(history.en)-1]);
ylim( [0, max(history.en)+1]);
set( gca, 'YScale', 'log');
set(gca,'YTick',[10^0, 10^1, 10^2, 10^3])

savePlot( h_fig, 'legPlotOversamplingOptimized');

%% Visualization of initial and final points

legPreVisualization;

for( i = 1 : numel(lambdas_opt))
  
  plot( lambdas_init(i), 0.0, 'o', 'Color', cols(i,:), ...
        'LineWidth', 1.25);
  plot( lambdas_opt(i), 0.0, 'x', 'Color', cols(i,:), ...
        'MarkerSize', 15, 'LineWidth', 1.25);

end

legPostVisualization;

savePlot( h_fig, 'legPlotOversamplingOptimized_lambdas');


