% Nonuniqueness of dual frame, example for R^2
%
% Adapted from Kovacevic, J., & Chebira, A. (2007). 
% Life Beyond Bases: The Advent of Frames (Part I). 
% Signal Processing Magazine, IEEE, 24(4), 86 ? 104. 
% doi:10.1109/MSP.2007.4286567

%% Set up frame and dual frames

% frame
B = [ 1 0 ; 0 1; 1 -1 ];

% dual frame
Bt_1 = pinv(B);
% Bt_2 = [ 2 -1 -1 ; 0 1 0 ];
Bt_2 = [ 1.2 -0.2 -0.2 ; 0 1 0 ];
  

%% Test basis property

T1 = Bt_1 * B - eye(2);
T2 = Bt_2 * B - eye(2);

disp( sprintf('Error basis property first dual frame: %e', sum(T1(:))));
disp( sprintf('Error basis property second dual frame: %e', sum(T2(:))));

%% Test reconstruction for random vector

vec = rand( 2, 1);

% compute basis function coefficients
v_1 = dot( vec, Bt_1(:,1));
v_2 = dot( vec, Bt_1(:,2));
v_3 = dot( vec, Bt_1(:,3));

vec_rec = v_1 * B(1,:)' +  v_2 * B(2,:)' +  v_3 * B(3,:)'; 

err = norm( vec - vec_rec);
disp( sprintf( 'Error for first dual basis: %e', err));


% compute basis function coefficients
v_1 = dot( vec, Bt_2(:,1));
v_2 = dot( vec, Bt_2(:,2));
v_3 = dot( vec, Bt_2(:,3));

vec_rec = v_1 * B(1,:)' +  v_2 * B(2,:)' +  v_3 * B(3,:)'; 

err = norm( vec - vec_rec);
disp( sprintf( 'Error for second dual basis: %e', err));

%% Plot frame and dual frames

x_min = -1.25;
x_max = 1.25;
y_min = -1.25;
y_max = 1.25;


plotR2Pre();
plotVector( B(1,:), '2.0-r');
plotVector( B(2,:), '2.0-r');
plotVector( B(3,:), '2.0-r');
savePlot( h_fig, 'plotDualFrameNonUniqueness_a');


plotR2Pre();
plotVector( Bt_1(:,1), '2.0-b');
plotVector( Bt_1(:,2), '2.0-b');
plotVector( Bt_1(:,3), '2.0-b');
savePlot( h_fig, 'plotDualFrameNonUniqueness_b');


plotR2Pre();
plotVector( Bt_2(:,1), '2.0-b');
plotVector( Bt_2(:,2), '2.0-b');
plotVector( Bt_2(:,3), '2.0-b');
savePlot( h_fig, 'plotDualFrameNonUniqueness_c');
