% Plot a biorthogonal basis in R2

%% Construct random biorthogonal basis.

% generate a random, non-orthogonal basis in R2
% B = 1.5 * rand( 2, 2);
% assert( cond( B ) < Inf);
% Fix B for reproducibility
B = [ 0 1 ; 
     -sqrt(3)/2  -1/2;
      sqrt(3)/2  -1/2];

% dual basis
Bt = pinv( B);

% We hence have: 
% \bar{e}_i = B(1,:);
% \tilde{e}_j = Bt(:,j);

%% Display

x_min = -1.0;
x_max = 1.0;
y_min = -0.6;
y_max = 1.025;

plotR2Pre();

% plot basis functions
plotVector( B(1,:), '1.5-r');
plotVector( B(2,:), '1.5-r');
plotVector( B(3,:), '1.5-r');

% adjust height
rect = get( gcf, 'OuterPosition');
rect(3) = 600;
rect(4) = 500;
set( gcf, 'OuterPosition', rect)

print('-depsc2','./figures/plotMercedesBenzFrame_a');


plotR2Pre();

% plot dual basis functions
plotVector( Bt(:,1), '1.5-b');
plotVector( Bt(:,2), '1.5-b');
plotVector( Bt(:,3), '1.5-b');
                              
% adjust height
rect = get( gcf, 'OuterPosition');
rect(3) = 600;
rect(4) = 500;
set( gcf, 'OuterPosition', rect)

print('-depsc2','./figures/plotMercedesBenzFrame_b');
